OC.L10N.register(
    "files",
    {
    "Added to favorites" : "已新增至喜愛",
    "Removed from favorites" : "已從喜愛中移除",
    "You added {file} to your favorites" : "您已新增 {file} 至您的喜愛",
    "You removed {file} from your favorites" : "您已從您的喜愛移除 {file}",
    "Favorites" : "喜愛",
    "File changes" : "檔案更動",
    "Created by {user}" : "由 {user} 建立",
    "Changed by {user}" : "由 {user} 變更",
    "Deleted by {user}" : "由 {user} 刪除",
    "Restored by {user}" : "由 {user} 還原",
    "Renamed by {user}" : "由 {user} 改名",
    "Moved by {user}" : "由 {user} 移動",
    "\"remote account\"" : "「遠端帳號」",
    "You created {file}" : "您建立了 {file}",
    "You created an encrypted file in {file}" : "您在 {file} 裡建立了一個加密的檔案",
    "{user} created {file}" : "{user} 建立了 {file}",
    "{user} created an encrypted file in {file}" : "{user} 在 {file} 裡建立了一個加密檔案",
    "{file} was created in a public folder" : "{file} 已建立於公開資料夾",
    "You changed {file}" : "您變更了 {file}",
    "You changed an encrypted file in {file}" : "您在 {file} 修改了一個加密的檔案",
    "{user} changed {file}" : "{user} 變更了 {file}",
    "{user} changed an encrypted file in {file}" : "{user} 在 {file} 裡修改了一個加密的檔案",
    "You deleted {file}" : "您刪除了 {file}",
    "You deleted an encrypted file in {file}" : "您在 {file} 刪除了一個加密的檔案",
    "{user} deleted {file}" : "{user} 刪除了 {file}",
    "{user} deleted an encrypted file in {file}" : "{user} 在 {file} 刪除了一個加密的檔案",
    "You restored {file}" : "您還原了 {file}",
    "{user} restored {file}" : "{user} 還原了 {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "您將 {oldfile}（隱藏）重新命名為 {newfile}（隱藏）",
    "You renamed {oldfile} (hidden) to {newfile}" : "您將 {oldfile}（隱藏）重新命名為 {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "您將 {oldfile} 重新命名為 {newfile}（隱藏）",
    "You renamed {oldfile} to {newfile}" : "您將 {oldfile} 重新命名為 {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} 將 {oldfile}（隱藏）重新命名為 {newfile}（隱藏）",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} 將 {oldfile}（隱藏）重新命名為 {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} 將 {oldfile} 重新命名為 {newfile}（隱藏）",
    "{user} renamed {oldfile} to {newfile}" : "{user} 將 {oldfile} 重新命名為 {newfile}",
    "You moved {oldfile} to {newfile}" : "您將 {oldfile} 移動到了 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 將 {oldfile} 移動到了 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "檔案已從您的<strong>喜愛</strong>新增或移除",
    "Files" : "檔案",
    "A file or folder has been <strong>changed</strong>" : "檔案或資料夾已被<strong>變更</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "一個喜愛的檔案或資料夾已<strong>變更</strong>",
    "Failed to authorize" : "授權失敗",
    "Invalid folder path" : "無效的資料夾路徑",
    "Folder not found" : "找不到資料夾",
    "The file cannot be found" : "找不到檔案",
    "The destination path does not exist: %1$s" : "目的路徑不存在：%1$s",
    "You do not have permission to create a file at the specified location" : "您無權在特定位置建立檔案",
    "The file could not be converted." : "無法轉換檔案。",
    "Could not get relative path to converted file" : "無法取得轉換檔案的相對路徑",
    "Favorite files" : "收藏檔案",
    "No favorites" : "沒有最愛",
    "More favorites" : "更多收藏",
    "Upload (max. %s)" : "上傳（最多 %s）",
    "Accept" : "接受",
    "Reject" : "拒絕",
    "Incoming ownership transfer from {user}" : "{user} 傳來的所有權轉移",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "您想要接受 {path} 嗎？\n\n註：所有權轉移的流程最多可能需要一小時。",
    "Ownership transfer denied" : "所有權轉移被拒絕",
    "Your ownership transfer of {path} was denied by {user}." : "您將 {path} 的所有權轉移給 {user} 時被拒絕。",
    "Ownership transfer failed" : "所有權轉移失敗",
    "Your ownership transfer of {path} to {user} failed." : "您將 {path} 的所有權轉移給 {user} 失敗。",
    "The ownership transfer of {path} from {user} failed." : "來自 {user} 的 {path} 所有權轉移失敗。",
    "Ownership transfer done" : "所有權轉移完成",
    "Your ownership transfer of {path} to {user} has completed." : "您將 {path} 的所有權轉移給 {user} 已完成。",
    "The ownership transfer of {path} from {user} has completed." : "來自 {user} 的 {path} 所有權轉移已完成。",
    "in %s" : "在 %s",
    "Transferred from %1$s on %2$s" : "於 %2$s 從 %1$s 轉移",
    "Files compatibility" : "檔案相容性",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限制檔案名稱以確保檔案可以與所有客戶端同步。預設情況下，允許 POSIX（例如 Linux 或 macOS）上所有有效的檔案名稱。",
    "Enforce Windows compatibility" : "強制 Windows 相容性",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這會封鎖在 Windows 系統上無效的檔案名稱，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的相容性。",
    "File Management" : "檔案管理",
    "Home" : "家目錄",
    "Target folder does not exist any more" : "目標資料夾已不存在了",
    "Reload current directory" : "重新載入目前的目錄",
    "Go to the \"{dir}\" directory" : "前往「{dir}」目錄",
    "Current directory path" : "目前目錄路徑",
    "Your have used your space quota and cannot upload files anymore" : "您已用完您的空間配額，無法再上傳檔案",
    "You do not have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
    "Drag and drop files here to upload" : "將檔案拖放到此處以上傳",
    "Favorite" : "喜愛",
    "Back" : "返回",
    "Toggle selection for file \"{displayName}\"" : "切換檔案「{displayName}」的選取",
    "Toggle selection for folder \"{displayName}\"" : "切換資料夾「{displayName}」的選取",
    "File is loading" : "正在載入檔案",
    "Folder is loading" : "正在載入資料夾",
    "Filename" : "檔案名稱",
    "Folder name" : "資料夾名稱",
    "This node is unavailable" : "此節點不可用",
    "Another entry with the same name already exists." : "已存在另一個同名條目。",
    "Invalid filename." : "無效的檔案名稱。",
    "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
    "Rename file" : "重新命名檔案",
    "Pending" : "待處理",
    "Unknown date" : "未知日期",
    "Clear filter" : "清除過濾條件",
    "Modified" : "修改時間",
    "Type" : "類型",
    "Active filters" : "作用中的過濾條件",
    "Remove filter" : "移除過濾條件",
    "Total rows summary" : "總列摘要",
    "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選取",
    "Name" : "名稱",
    "Size" : "大小",
    "\"{displayName}\" failed on some elements" : "「{displayName}」在某些元素上失敗",
    "\"{displayName}\" batch action executed successfully" : "「{displayName}」批次動作執行成功",
    "\"{displayName}\" action failed" : "「{displayName}」操作失敗",
    "Actions" : "動作",
    "(selected)" : "（已選取）",
    "List of files and folders." : "檔案與資料夾清單。",
    "You have used your space quota and cannot upload files anymore." : "您已用完您的空間配額，無法再上傳檔案。",
    "Column headers with buttons are sortable." : "帶有按鈕的欄位標頭為可排序。",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於效能考量，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
    "File not found" : "找不到檔案",
    "{count} selected" : "已選取 {count} 個",
    "{usedQuotaByte} used" : "已使用 {usedQuotaByte}",
    "{used} of {quota} used" : "已使用 {used}，共 {quota}",
    "{relative}% used" : "已使用 {relative}%",
    "Could not refresh storage stats" : "無法重新整理儲存空間統計資料",
    "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Storage information" : "儲存空間資訊",
    "Storage quota" : "儲存空間配額",
    "New folder" : "新資料夾",
    "Create new folder" : "新增資料夾",
    "This name is already in use." : "此名稱已使用。",
    "Create" : "建立",
    "Fill template fields" : "檔案範本欄位",
    "Submitting fields …" : "正在遞交欄位……",
    "Submit" : "遞交",
    "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
    "Transfer" : "轉移",
    "Transfer {path} to {userid}" : "轉移 {path} 給 {userid}",
    "Invalid path selected" : "選取的路徑無效",
    "Unknown error" : "未知的錯誤",
    "Ownership transfer request sent" : "已送出所有權轉移的請求",
    "Cannot transfer ownership of a file or folder you do not own" : "無法轉移您未擁有的檔案或資料夾的所有權",
    "Transfer ownership of a file or folder" : "轉移檔案或是資料夾的所有權",
    "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
    "Change" : "更改",
    "New owner" : "新的擁有者",
    "Keep {old}" : "保留 {old}",
    "Keep without extension" : "保留但不包含副檔名",
    "Use {new}" : "使用 {new}",
    "Remove extension" : "移除副檔名",
    "Change file extension" : "變更檔案副檔名",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "將檔案副檔名從「{old}」改為「{new}」可能會導致檔案無法讀取。",
    "Removing the file extension \"{old}\" may render the file unreadable." : "移除檔案副檔名「{old}」可能會導致檔案無法讀取。",
    "Adding the file extension \"{new}\" may render the file unreadable." : "加入檔案副檔名「{new}」可能會導致檔案無法讀取。",
    "Do not show this dialog again." : "不要再次顯示此對話方塊。",
    "Select file or folder to link to" : "選取要連結的檔案或資料夾",
    "Choose {file}" : "選擇 {file}",
    "Share" : "分享",
    "Shared by link" : "透過連結分享",
    "Shared" : "已分享",
    "Switch to list view" : "切換至列表檢視",
    "Switch to grid view" : "切換到格狀檢視",
    "The file could not be found" : "找不到檔案",
    "Upload was cancelled by user" : "使用者已取消上傳",
    "Not enough free space" : "空間不足",
    "Operation is blocked by access control" : "操作已被存取控制封鎖",
    "Error during upload: {message}" : "上傳時發生錯誤：{message}",
    "Error during upload, status code {status}" : "上傳時發生錯誤，狀態碼 {status}",
    "Unknown error during upload" : "上傳時發生未知的錯誤",
    "\"{displayName}\" action executed successfully" : "「{displayName}」動作執行成功",
    "Loading current folder" : "正在載入目前資料夾",
    "Retry" : "重試",
    "No files in here" : "沒有任何檔案",
    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
    "Go back" : "返回",
    "Filter file names …" : "過濾檔案名稱……",
    "Views" : "顯示",
    "Files settings" : "檔案設定",
    "Your files" : "您的檔案",
    "Open in files" : "在檔案中開啟",
    "File cannot be accessed" : "無法存取檔案",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請寄件者分享。",
    "Clipboard is not available" : "剪貼簿無法使用",
    "WebDAV URL copied to clipboard" : "WebDAV URL 已複製到剪貼簿",
    "Sort favorites first" : "先排序喜愛",
    "Sort folders before files" : "將資料夾排序在檔案前",
    "Show hidden files" : "顯示隱藏檔",
    "Crop image previews" : "圖片裁剪預覽",
    "Enable the grid view" : "啟用格狀檢視",
    "Enable folder tree" : "啟用資料夾樹",
    "Additional settings" : "其他設定",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "複製到剪貼簿",
    "Use this address to access your Files via WebDAV" : "使用此位置透過 WebDAV 存取您的檔案",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "若您啟用了雙因子認證，您必須點擊此處建立並使用新的應用程式密碼。",
    "Warnings" : "警告",
    "Prevent warning dialogs from open or reenable them." : "避免開啟警告對話方塊或重新啟用它們。",
    "Show a warning dialog when changing a file extension." : "在變更副檔名時顯示警告對話方塊。",
    "Keyboard shortcuts" : "鍵盤快速鍵",
    "Speed up your Files experience with these quick shortcuts." : "使用這些快捷鍵加速您的 Files 體驗。",
    "Open the actions menu for a file" : "開啟檔案的動作選單",
    "Rename a file" : "重新命名檔案",
    "Delete a file" : "刪除檔案",
    "Favorite or remove a file from favorites" : "加入最愛或從最愛移除檔案",
    "Manage tags for a file" : "管理檔案的標籤",
    "Selection" : "選取",
    "Select all files" : "選取所有檔案",
    "Deselect all files" : "取消選取所有檔案",
    "Select or deselect a file" : "選取或取消選取檔案",
    "Select a range of files" : "選取檔案範圍",
    "Navigation" : "導覽列",
    "Navigate to the parent folder" : "前往上層資料夾",
    "Navigate to the file above" : "前往上述檔案",
    "Navigate to the file below" : "前往以下檔案",
    "Navigate to the file on the left (in grid mode)" : "前往左側的檔案（在網格模式下）",
    "Navigate to the file on the right (in grid mode)" : "前往右側的檔案（在網格模式下）",
    "View" : "檢視",
    "Toggle the grid view" : "切換網格檢視",
    "Open the sidebar for a file" : "開啟檔案側邊欄",
    "Show those shortcuts" : "顯示這些快捷鍵",
    "You" : "您",
    "Shared multiple times with different people" : "與不同的人多次分享",
    "Error while loading the file data" : "載入檔案資料時發生錯誤",
    "Owner" : "擁有者",
    "Remove from favorites" : "從喜愛中移除",
    "Add to favorites" : "新增至喜愛",
    "Tags" : "標籤",
    "Blank" : "空白",
    "Unable to create new file from template" : "無法從範本建立新檔案",
    "Pick a template for {name}" : "為 {name} 挑選範本",
    "Create a new file with the selected template" : "使用選定的範本建立新檔案",
    "Creating file" : "正在建立檔案",
    "Save as {displayName}" : "另存為 {displayName}",
    "Save as …" : "另存為……",
    "Converting files …" : "正在轉換檔案……",
    "Failed to convert files: {message}" : "無法轉換檔案：{message}",
    "All files failed to be converted" : "所有檔案轉換失敗",
    "One file could not be converted: {message}" : "一個檔案無法轉換：{message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["無法轉換 %n 個檔案"],
    "_One file successfully converted_::_%n files successfully converted_" : ["成功轉換 %n 個檔案"],
    "Files successfully converted" : "檔案成功轉換",
    "Failed to convert files" : "轉換檔案失敗",
    "Converting file …" : "正在轉換檔案……",
    "File successfully converted" : "成功轉換檔案",
    "Failed to convert file: {message}" : "無法轉換檔案：{message}",
    "Failed to convert file" : "無法轉換檔案",
    "Deletion cancelled" : "刪除已取消",
    "Leave this share" : "離開此分享",
    "Leave these shares" : "離開這些分享",
    "Disconnect storage" : "中斷連結儲存空間",
    "Disconnect storages" : "解除連結儲存空間",
    "Delete permanently" : "永久刪除",
    "Delete and unshare" : "刪除並取消分享",
    "Delete file" : "刪除檔案",
    "Delete files" : "刪除檔案",
    "Delete folder" : "刪除資料夾",
    "Delete folders" : "刪除資料夾",
    "Delete" : "刪除",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您將要永久刪除 {count} 個項目"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您將要刪除 {count} 個項目"],
    "Confirm deletion" : "確認刪除",
    "Cancel" : "取消",
    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」……",
    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」……",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
    "(copy)" : "（副本）",
    "(copy %n)" : "（副本 %n）",
    "Move cancelled" : "移動已取消",
    "A file or folder with that name already exists in this folder" : "此資料夾中已經存在同名的檔案或資料夾",
    "The files are locked" : "檔案已鎖定",
    "The file does not exist anymore" : "檔案已不存在",
    "Choose destination" : "選擇目的地",
    "Copy to {target}" : "複製到 {target}",
    "Copy" : "複製",
    "Move to {target}" : "移動到 {target}",
    "Move" : "移動",
    "Move or copy operation failed" : "移動或複製操作失敗",
    "Move or copy" : "移動或複製",
    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製「{filename}」。",
    "Cancelled move or copy operation" : "已取消移動或複製操作",
    "Open folder {displayName}" : "開啟資料夾 {displayName}",
    "Open in Files" : "以「檔案」開啟",
    "Open file locally" : "在本機開啟檔案",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "檔案現在應該可以在您的裝置上開啟。如果打不開，請檢查您是否有安裝桌面應用程式。",
    "Retry and close" : "重試並關閉",
    "Open online" : "線上開啟",
    "Failed to redirect to client" : "重新導向到客戶端失敗",
    "Open locally" : "在本機開啟",
    "Rename" : "重新命名",
    "Open details" : "開啟詳細資訊",
    "View in folder" : "在資料夾中檢視",
    "Today" : "今日",
    "Last 7 days" : "過去7天",
    "Last 30 days" : "過去30天",
    "This year ({year})" : "今年 ({year})",
    "Last year ({year})" : "去年 ({year})",
    "Documents" : "文件",
    "Spreadsheets" : "試算表",
    "Presentations" : "簡報",
    "PDFs" : "PDF",
    "Folders" : "資料夾",
    "Audio" : "音訊",
    "Photos and images" : "照片與影像",
    "Videos" : "影片",
    "New folder creation cancelled" : "已取消建立新資料夾",
    "Created new folder \"{name}\"" : "已建立新資料夾「{name}」",
    "Unable to initialize the templates directory" : "無法初始化範本目錄",
    "Create templates folder" : "建立範本資料夾",
    "Templates" : "範本",
    "New template folder" : "新範本資料夾",
    "In folder" : "在資料夾中",
    "Search in folder: {folder}" : "在資料夾中搜尋：{folder}",
    "One of the dropped files could not be processed" : "無法處理其中一個投遞的檔案",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "您的瀏覽器不支援檔案系統 API。將不會上傳目錄",
    "No files to upload" : "沒有要上傳的檔案",
    "Unable to create the directory {directory}" : "無法建立目錄 {directory}",
    "Some files could not be uploaded" : "無法上傳部份檔案",
    "Files uploaded successfully" : "檔案上傳成功",
    "No files to process" : "沒有要處理的檔案",
    "Some files could not be copied" : "無法複製部份檔案",
    "Some files could not be moved" : "有些檔案無法被移動",
    "Files copied successfully" : "檔案複製成功",
    "Files moved successfully" : "檔案移動成功",
    "Conflicts resolution skipped" : "已略過衝突解決",
    "Upload cancelled" : "已取消上傳",
    "This operation is forbidden" : "此操作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法取用，請檢查伺服器紀錄檔或聯絡管理員",
    "Storage is temporarily not available" : "儲存空間暫時無法使用",
    "Unexpected error: {error}" : "意外錯誤：{error}",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
    "Filename must not be empty." : "檔案名稱不能為空。",
    "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "「{segment}」是保留名稱，不允許用在檔案名稱。",
    "\"{extension}\" is not an allowed filetype." : "「{extension}」是不允許的檔案類型。",
    "Filenames must not end with \"{extension}\"." : "檔案名稱不能以「{extension}」結尾。",
    "List of favorite files and folders." : "最愛檔案與資料夾清單。",
    "No favorites yet" : "尚無喜愛",
    "Files and folders you mark as favorite will show up here" : "您標記為喜愛的檔案與資料夾將會顯示在這裡",
    "All files" : "所有檔案",
    "List of your files and folders." : "您的檔案與資料夾清單。",
    "All folders" : "所有資料夾",
    "Personal files" : "個人檔案",
    "List of your files and folders that are not shared." : "未分享的檔案與資料夾清單。",
    "No personal files found" : "找不到個人檔案",
    "Files that are not shared will show up here." : "尚未分享的檔案將會顯示在此處。",
    "Recent" : "最近",
    "List of recently modified files and folders." : "最近修改的檔案與資料夾的清單。",
    "No recently modified files" : "最近無修改檔案",
    "Files and folders you recently modified will show up here." : "您最近修改的檔案與資料夾將會顯示在此處。",
    "No entries found in this folder" : "此資料夾中沒有任何項目",
    "Select all" : "全選",
    "Upload too large" : "上傳檔案過大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制。",
    "File could not be found" : "找不到檔案",
    "Download" : "下載",
    "Show list view" : "顯示清單檢視",
    "Show grid view" : "顯示格狀檢視",
    "Close" : "關閉",
    "Could not create folder \"{dir}\"" : "無法建立資料夾「{dir}」",
    "This will stop your current uploads." : "這會停止您目前的上傳。",
    "Upload cancelled." : "上傳已取消。",
    "Processing files …" : "正在處理檔案…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，您正要上傳 {size1} 可是只剩下 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "目標資料夾「{dir}」不存在",
    "An unknown error has occurred" : "發生未知的錯誤",
    "File could not be uploaded" : "檔案無法上傳",
    "Uploading …" : "正在上傳…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "正在上傳… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize} ({bitrate})",
    "Uploading that item is not supported" : "不支援上傳該項目",
    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
    "Choose target folder" : "選擇目標資料夾",
    "Set reminder" : "設定提醒",
    "Edit locally" : "在本機編輯",
    "Open" : "開啟",
    "Could not load info for file \"{file}\"" : "無法讀取「{file}」的詳細資料",
    "Details" : "詳細資料",
    "Please select tag(s) to add to the selection" : "請選取要新增到選定項目的標籤",
    "Apply tag(s) to selection" : "將標籤套用至選定項目",
    "Select directory \"{dirName}\"" : "選取目錄「{dirName}」",
    "Select file \"{fileName}\"" : "選取檔案「{fileName}」",
    "Unable to determine date" : "無法確定日期",
    "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
    "Could not move \"{file}\"" : "無法移動「{file}」",
    "copy" : "複製",
    "Could not copy \"{file}\", target exists" : "無法複製「{file}」，目標已經存在",
    "Could not copy \"{file}\"" : "無法複製「{file}」",
    "Copied {origin} inside {destination}" : "已將 {origin} 複製到 {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "已將 {origin} 和其他 {nbfiles} 個檔案複製到 {destination}",
    "{newName} already exists" : "{newName} 已經存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案「{fileName}」，因為檔案已不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱「{targetName}」在這資料夾「{dir}」中已被使用。請改用其他名稱。",
    "Could not rename \"{fileName}\"" : "無法重新命名「{fileName}」",
    "Could not create file \"{file}\"" : "無法建立檔案「{file}」",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已經存在",
    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾「{dir}」，因為此資料夾已經存在",
    "Could not fetch file details \"{file}\"" : "無法擷取檔案詳細資訊「{file}」",
    "Error deleting file \"{fileName}\"." : "刪除「{fileName}」時發生錯誤。",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其他資料夾中沒有找到 {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "請輸入兩個字元以上，以便在其他資料夾搜尋",
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "_%n file_::_%n files_" : ["%n 個檔案"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包含 %n 個隱藏檔"],
    "You do not have permission to upload or create files here" : "您無權在此上傳或建立檔案",
    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
    "New" : "新增",
    "New file/folder menu" : "新檔案/資料夾選單",
    "Select file range" : "選取多個檔案",
    "{used}%" : "{used}%",
    "{used} used" : "已使用 {used}",
    "\"{name}\" is an invalid file name." : "「{name}」是無效的檔名。",
    "File name cannot be empty." : "檔名不能為空。",
    "\"/\" is not allowed inside a file name." : "不允許檔名中出現「/」。",
    "\"{name}\" is not an allowed filetype" : "「{name}」是不允許的檔案類型",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的儲存空間已滿，已無法再更新或是同步檔案！",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群組資料夾「{mountPoint}」已滿，已無法再更新或同步檔案！",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部儲存空間「{mountPoint}」已滿，已無法再更新或同步檔案！",
    "Your storage is full, files cannot be updated or synced anymore!" : "您的儲存空間已滿，已無法再更新或是同步檔案！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的儲存空間將近已滿 ({usedSpacePercent}%)。",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "群組資料夾「{mountPoint}」將近已滿 ({usedSpacePercent}%)。",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部儲存空間「{mountPoint}」將近已滿 ({usedSpacePercent}%)。",
    "Your storage is almost full ({usedSpacePercent}%)." : "您的儲存空間將近已滿 ({usedSpacePercent}%)。",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["符合「{filter}」"],
    "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
    "Path" : "路徑",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Favorited" : "已加入喜愛",
    "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
    "Upload file" : "上傳檔案",
    "Not favorited" : "未加入至喜愛",
    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
    "You don't have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
    "Storage informations" : "儲存空間資訊",
    "Choose file" : "選擇檔案",
    "Go to the previous folder" : "前往上一個資料夾",
    "Open the files app settings" : "開啟檔案應用程式設定",
    "Unable to change the favourite state of the file" : "無法更改檔案的喜愛狀態",
    "Edit file locally" : "本機編輯檔案",
    "Edit online" : "線上編輯",
    "Create new templates folder" : "建立新的範本資料夾",
    "List of favorites files and folders." : "喜愛檔案與資料夾的清單。",
    "Personal Files" : "個人檔案",
    "Text file" : "文字檔案",
    "New text file.txt" : "新文字檔案.txt",
    "Favored" : "已加入最愛",
    "Favor" : "加入最愛",
    "Not favored" : "未加入最愛",
    "Submitting fields…" : "正在遞交欄位……",
    "Filter filenames…" : "篩選檔案名稱……",
    "{count} files could not be converted" : "{count} 個檔案無法轉換",
    "{count} files successfully converted" : "{count} 個檔案成功轉換"
},
"nplurals=1; plural=0;");
